jiffybox
========

A wrapper around the API of JiffyBox (http://jiffybox.de)
Consisting of a :ref:`python library <api>`
and a :ref:`command line program <cli>` using the library.

Docs: http://python-jiffybox.readthedocs.io

Downloads: https://pypi.python.org/pypi/jiffybox/

Current features
----------------

* Access to the basic API elements

Planned features
----------------

* Implement the whole API
* Make string version of objects less ugly
* Tests

Underlying API
--------------

The upstream HTTP API this library is using is documented on
https://www.df.eu/fileadmin/media/doc/jiffybox-api-dokumentation.pdf.

Note
----

.. WARNING::
  This library is in **no** way affiliated with domainFACTORY, the provider of the
  JiffyBox service.

License
-------

GPL3
